<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Pasien;
use App\Imports\PasienImport;
use Maatwebsite\Excel\Facades\Excel;

class PasienController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Helper::hakAkses('Pasien','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = 'Pasien';
        $url = 'pasien';
        $menu = 'Pasien';

        $pasien = Pasien::all();
        return view('pasien.index', compact('title', 'url', 'menu', 'pasien'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Helper::hakAkses('Pasien','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $title = 'Pasien';
        $url = 'pasien';
        $menu = 'Pasien';

        return view('pasien.create', compact('title', 'url', 'menu'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        if(!\Helper::hakAkses('Pasien','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $this->validate($request, [
            'nomor_pasien' => 'required',
            'nama_pasien' => 'required',
            'alamat' => 'required',
            'no_hp' => 'required',
        ]);
            
        try {
        $pasien = Pasien::create([
            'nomor_pasien' => $request->nomor_pasien,
            'nama_pasien' => $request->nama_pasien,
            'alamat' => $request->alamat,
            'no_hp' => $request->no_hp,
        ]);

        \Helper::addUserLog('menambah data Pasien '.$request->nama_pasien,$pasien->toArray());

        return redirect()->route('pasien.index')->with('success', 'Data Berhasil Ditambahkan');

        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!\Helper::hakAkses('Pasien','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $pasien = Pasien::find($id);
        $title = "Pasien";
        $url = "pasien";
        $menu = "Pasien";
        
        return view('pasien.edit', compact('title', 'url', 'menu', 'pasien'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(!\Helper::hakAkses('Pasien','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {
            $pasien = Pasien::find($id);
            $old = $pasien->toArray();
            $pasien->update([
                'nama_pasien' => $request->nama_pasien,
                'alamat' => $request->alamat,
                'no_hp' => $request->no_hp,
            ]);

            \Helper::addUserLog('Mengubah Data Pasien '.$request->nama_pasien,[
                'old'=>$old,
                'update'=>$pasien->toArray()
            ]);

            return redirect(route('pasien.index'))->with('success', 'Data Berhasil Diubah');
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!\Helper::hakAkses('Pasien','Delete')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {    
            $pasien = Pasien::find($id);            
            $nama = $pasien->nama_pasien;
            $pasien->delete();
            \Helper::addUserLog('Menghapus Data Pasien '.$nama,$pasien->toArray());        
           
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

        return redirect(route('pasien.index'))->with('success', 'Data Berhasil Dihapus');
    }

    public function upload()
    {
        if(!\Helper::hakAkses('Pasien','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $title = 'Pasien';
        $url = 'pasien';
        $menu = 'Pasien';

        return view('pasien.upload', compact('title', 'url', 'menu'));
    }


    public function storeUpload(Request $request)
    {
        if(!\Helper::hakAkses('Pasien','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $excel = new PasienImport();
        Excel::import($excel, $request->file);
        
        return redirect(route('pasien.index'))->with('success', 'Berhasil Import Data!');
    }
}
